@@ -166,6 +166,7 @@ class Column:
         '''The default value set to this column if no data is provided.'''
         column_key:str = None
         column_name:str = None
+        '''The name of this column in the table.'''
         column_type:str = None
         data_type:str = None
         datetime_precision:str = None
@@ -517,6 +518,34 @@ class Column:
         value_options = None
 
 
+        # ------------------------------ CREATE OPTIONS ------------------------------ #
+        create_post_args:bool = False
+        '''True if this column can be provided as a post argument in a create operation'''
+
+        create_post_arg_required:bool = False
+        '''True if this column is a required post argument to perform a create operation '''
+
+
+
+        # ------------------------------ READ OPTIONS ------------------------------ #
+        read_post_args:bool = True
+        '''True if the this column can be searched for (allowed to be a where clause value)'''
+
+
+
+        # ------------------------------ UPDATE OPTIONS ------------------------------ #
+        update_post_args:bool = False
+        '''True if this column is allowed to be referenced in a post argument for an update operation'''
+
+        update_allow_change:bool = False
+        '''True if this column's value is allowed to be updated'''
+
+
+
+        # ------------------------------ DELETE OPTIONS ------------------------------ #
+        delete_post_args:bool = False
+
+
 
 
         def __init__(self,column:_db_column_type):
@@ -549,6 +578,11 @@ class Column:
                 "read_validation_schema":self.cerberus_schema("read",True),
                 "update_validation_schema":self.cerberus_schema("update",True),
                 "delete_validation_schema":self.cerberus_schema("delete",True),
+                "create_post_args":self.create_post_args,
+                "read_post_args":self.read_post_args,
+                "update_post_args":self.update_post_args,
+                "update_allow_change":self.update_allow_change,
+                "delete_post_args":self.delete_post_args,
             }
             return value
 
@@ -731,6 +765,32 @@ class Column:
 
             return value
 
+        @property
+        def allowed_in_create(self):
+            '''
+                Get this Column's allowed_in_create
+
+                `default`:None
+
+
+                Meta
+                ----------
+                `@author`: Colemen Atwood
+                `@created`: 12-13-2022 14:40:33
+                `@memberOf`: Column
+                `@property`: allowed_in_create
+            '''
+            allowed = True
+            if self.no_create_post_args is True:
+                allowed = False
+            if self._column.form.create_form is False:
+                allowed = False
+            if self._column.form.no_create is True:
+                allowed = False
+            return allowed
+
+
+
     @dataclass
     class form_data:
         _column:_db_column_type = None
