@@ -3,8 +3,8 @@
 # pylint: disable=line-too-long
 # pylint: disable=unused-import
 
-# from typing import TYPE_CHECKING
-# from typing import TypeVar as _TypeVar
+from typing import TYPE_CHECKING
+from typing import TypeVar as _TypeVar
 
 
 # import colemen_utilities.database_utils.MySQL.MySQLDatabase as mysqlDB
@@ -21,8 +21,8 @@ from colemen_utilities.database_utils.MySQL.MySQLDatabase import MySQLDatabase a
 from colemen_utilities.database_utils.MySQL.MySQLDatabase import new
 
 
-# if TYPE_CHECKING:
-#     import colemen_utilities.database_utils.MySQL.Table.Table as _table
-#     _db_table_type = _TypeVar('_db_table_type', bound=_table.Table)
+if TYPE_CHECKING:
+    import colemen_utilities.database_utils.MySQL.Table.Table as _table
+    _db_table_type = _TypeVar('_db_table_type', bound=_table.Table)
 
 
